@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-"""A Python module for dealing with NUT (Network UPS Tools) servers.
+"""A Python3 module for dealing with NUT (Network UPS Tools) servers.
 
 * PyNUT3Error: Base class for custom exceptions.
 * PyNUT3Client: Allows connecting to and communicating with PyNUT servers.
@@ -31,7 +31,7 @@ import socket
 from telnetlib import Telnet
 from typing import Any, Dict, List, Optional
 
-__version__ = '0.1.0'
+__version__ = '0.2.0'
 __all__ = ['PyNUT3Error', 'PyNUT3Client']
 
 _LOGGER = logging.getLogger(__name__)
@@ -47,9 +47,11 @@ class PyNUT3Error(Exception):
 class PyNUT3Client:
     """Access NUT (Network UPS Tools) servers."""
 
+    # pylint: disable=too-many-instance-attributes
     def __init__(self, host: str = '127.0.0.1', port: int = 3493,
                  login: Optional[str] = None, password: Optional[str] = None,
-                 timeout: float = 5, persistent: bool = True) -> None:
+                 timeout: float = 5, persistent: bool = True,
+                 debug: bool = True) -> None:
         """Class initialization method.
 
         host        : Host to connect (defaults to 127.0.0.1).
@@ -62,10 +64,12 @@ class PyNUT3Client:
         persistent  : Boolean, when true connection will be made in init method
                         and be held open, when false connection is open/closed
                         when calling each method
+        debug       : Boolean, put class in debug mode (prints everything
+                        on console, defaults to False).
         """
-
         _LOGGER.debug(f'NUT Class initialization, Host/Port: {host}:{port}, Login: {login}')
 
+        self._debug = debug
         self._host: str = host
         self._port: int = port
         self._login: Optional[str] = login
@@ -160,7 +164,7 @@ class PyNUT3Client:
         except IndexError as exc:
             raise PyNUT3Error(result.replace('\n', '')) from exc
 
-    def list_ups(self) -> Dict[str, str]:
+    def get_dict_ups(self) -> Dict[str, str]:
         """Returns the list of available UPS from the NUT server.
 
         The result is a dictionary containing 'key->val' pairs of
@@ -195,7 +199,7 @@ class PyNUT3Client:
 
         return ups_dict
 
-    def list_vars(self, ups: str) -> Dict[str, str]:
+    def get_dict_vars(self, ups: str) -> Dict[str, str]:
         """Get all available vars from the specified UPS.
 
         The result is a dictionary containing 'key->val' pairs of all
@@ -231,7 +235,7 @@ class PyNUT3Client:
 
         return ups_vars
 
-    def list_commands(self, ups: str) -> Dict[str, str]:
+    def get_dict_commands(self, ups: str) -> Dict[str, str]:
         """Get all available commands for the specified UPS.
 
         The result is a dict object with command name as key and a description
@@ -276,7 +280,7 @@ class PyNUT3Client:
 
         return commands
 
-    def list_clients(self, ups: str = '') -> Dict[str, List[str]]:
+    def get_dict_clients(self, ups: str = '') -> Dict[str, List[str]]:
         """Returns the list of connected clients from the NUT server.
 
         The result is a dictionary containing 'key->val' pairs of
@@ -287,7 +291,7 @@ class PyNUT3Client:
         if not self._persistent:
             self._connect()
 
-        if ups and (ups not in self.list_ups()):
+        if ups and (ups not in self.get_dict_ups()):
             raise PyNUT3Error(f'{ups} is not a valid UPS')
 
         if ups:
@@ -318,7 +322,7 @@ class PyNUT3Client:
 
         return clients
 
-    def list_rw_vars(self, ups: str) -> Dict[str, str]:
+    def get_dict_rw_vars(self, ups: str) -> Dict[str, str]:
         """Get a list of all writable vars from the selected UPS.
 
         The result is presented as a dictionary containing 'key->val'
@@ -529,7 +533,7 @@ class PyNUT3Client:
             self._disconnect()
 
     def fsd(self, ups: str) -> None:
-        """Send MASTER and FSD commands."""
+        """Send MASTER and Forced ShutDown (FSD) commands."""
         _LOGGER.debug("NUT3 MASTER called on '{self._host}'.")
 
         if not self._persistent:
